==> kubernetes-model-core-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/NamedClusterFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NamedClusterFluentImpl<A extends io.fabric8.kubernetes.api.model.NamedClusterFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NamedClusterFluent<A>{
  public NamedClusterFluentImpl() {
  }
  public NamedClusterFluentImpl(io.fabric8.kubernetes.api.model.NamedCluster instance) {
    this.withCluster(instance.getCluster()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ClusterBuilder cluster;
  private java.lang.String name;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCluster instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Cluster getCluster() {
    return this.cluster!=null?this.cluster.build():null;
  }
  public io.fabric8.kubernetes.api.model.Cluster buildCluster() {
    return this.cluster!=null?this.cluster.build():null;
  }
  public A withCluster(io.fabric8.kubernetes.api.model.Cluster cluster) {
    _visitables.get("cluster").remove(this.cluster);
    if (cluster!=null){ this.cluster= new io.fabric8.kubernetes.api.model.ClusterBuilder(cluster); _visitables.get("cluster").add(this.cluster);} return (A) this;
  }
  public java.lang.Boolean hasCluster() {
    return this.cluster != null;
  }
  public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> withNewCluster() {
    return new io.fabric8.kubernetes.api.model.NamedClusterFluentImpl.ClusterNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> withNewClusterLike(io.fabric8.kubernetes.api.model.Cluster item) {
    return new io.fabric8.kubernetes.api.model.NamedClusterFluentImpl.ClusterNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> editCluster() {
    return withNewClusterLike(getCluster());
  }
  public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> editOrNewCluster() {
    return withNewClusterLike(getCluster() != null ? getCluster(): new io.fabric8.kubernetes.api.model.ClusterBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> editOrNewClusterLike(io.fabric8.kubernetes.api.model.Cluster item) {
    return withNewClusterLike(getCluster() != null ? getCluster(): item);
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NamedClusterFluentImpl that = (NamedClusterFluentImpl) o;
    if (cluster != null ? !cluster.equals(that.cluster) :that.cluster != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cluster,  name,  additionalProperties,  super.hashCode());
  }
  public class ClusterNestedImpl<N> extends io.fabric8.kubernetes.api.model.ClusterFluentImpl<io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<N>> implements io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ClusterNestedImpl(io.fabric8.kubernetes.api.model.Cluster item) {
      this.builder = new io.fabric8.kubernetes.api.model.ClusterBuilder(this, item);
    }
    ClusterNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ClusterBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ClusterBuilder builder;
    public N and() {
      return (N) NamedClusterFluentImpl.this.withCluster(builder.build());
    }
    public N endCluster() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/NamedClusterFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NamedClusterFluentImpl<A extends io.fabric8.kubernetes.api.model.NamedClusterFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NamedClusterFluent<A>{
  public NamedClusterFluentImpl() {
  }
  public NamedClusterFluentImpl(io.fabric8.kubernetes.api.model.NamedCluster instance) {
    this.withCluster(instance.getCluster()); 
    this.withName(instance.getName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.ClusterBuilder cluster;
  private java.lang.String name;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCluster instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Cluster getCluster() {
    return this.cluster!=null?this.cluster.build():null;
  }
  public io.fabric8.kubernetes.api.model.Cluster buildCluster() {
    return this.cluster!=null?this.cluster.build():null;
  }
  public A withCluster(io.fabric8.kubernetes.api.model.Cluster cluster) {
    _visitables.get("cluster").remove(this.cluster);
    if (cluster!=null){ this.cluster= new io.fabric8.kubernetes.api.model.ClusterBuilder(cluster); _visitables.get("cluster").add(this.cluster);} return (A) this;
  }
  public java.lang.Boolean hasCluster() {
    return this.cluster != null;
  }
  public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> withNewCluster() {
    return new io.fabric8.kubernetes.api.model.NamedClusterFluentImpl.ClusterNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> withNewClusterLike(io.fabric8.kubernetes.api.model.Cluster item) {
    return new io.fabric8.kubernetes.api.model.NamedClusterFluentImpl.ClusterNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> editCluster() {
    return withNewClusterLike(getCluster());
  }
  public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> editOrNewCluster() {
    return withNewClusterLike(getCluster() != null ? getCluster(): new io.fabric8.kubernetes.api.model.ClusterBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<A> editOrNewClusterLike(io.fabric8.kubernetes.api.model.Cluster item) {
    return withNewClusterLike(getCluster() != null ? getCluster(): item);
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NamedClusterFluentImpl that = (NamedClusterFluentImpl) o;
    if (cluster != null ? !cluster.equals(that.cluster) :that.cluster != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cluster,  name,  additionalProperties,  super.hashCode());
  }
  public class ClusterNestedImpl<N> extends io.fabric8.kubernetes.api.model.ClusterFluentImpl<io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<N>> implements io.fabric8.kubernetes.api.model.NamedClusterFluent.ClusterNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ClusterNestedImpl(io.fabric8.kubernetes.api.model.Cluster item) {
      this.builder = new io.fabric8.kubernetes.api.model.ClusterBuilder(this, item);
    }
    ClusterNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ClusterBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ClusterBuilder builder;
    public N and() {
      return (N) NamedClusterFluentImpl.this.withCluster(builder.build());
    }
    public N endCluster() {
      return and();
    }
    
  }
  
}
